pub(crate) enum AttributeEntry {
Raw(ContentAttributeData),
Dom(Dom<Attr>),
}Expand description
A single attribute entry, either lightweight raw data or a full DOM Attr node.
Variants
Raw(ContentAttributeData)
Lightweight data — no Attr DOM node allocated.
Dom(Dom<Attr>)
Full Attr DOM node.
Implementations
Sourceimpl AttributeEntry
impl AttributeEntry
Sourcepub(crate) fn value_for_layout(&self) -> &AttrValue
pub(crate) fn value_for_layout(&self) -> &AttrValue
Get the value of this attribute for layout.
Sourcepub(crate) fn local_name_for_layout(&self) -> &LocalName
pub(crate) fn local_name_for_layout(&self) -> &LocalName
Get the local name of this attribute for layout.
Sourcepub(crate) fn namespace_for_layout(&self) -> &Namespace
pub(crate) fn namespace_for_layout(&self) -> &Namespace
Get the namespace of this attribute for layout.