pub(crate) struct AttributeStorage(DomRefCell<Vec<AttributeEntry>>);Expand description
Storage for an element’s attributes. Contains an internal DomRefCell so that
ensure_dom can split its borrow around Attr::new() allocation, preventing
GC-during-allocation panics from double-borrowing.
Tuple Fields
0: DomRefCell<Vec<AttributeEntry>>Implementations
Sourceimpl AttributeStorage
impl AttributeStorage
Sourcepub(crate) fn borrow(&self) -> AttributesBorrow<'_>
pub(crate) fn borrow(&self) -> AttributesBorrow<'_>
Borrow the attributes for read access with convenient AttrRef iteration.
Sourcepub(crate) unsafe fn borrow_for_layout(&self) -> &Vec<AttributeEntry>
pub(crate) unsafe fn borrow_for_layout(&self) -> &Vec<AttributeEntry>
Borrow the underlying entries for layout access (unsafe).
Sourcepub(crate) fn push_raw(&self, data: ContentAttributeData)
pub(crate) fn push_raw(&self, data: ContentAttributeData)
Push raw attribute data.
Sourcepub(crate) fn remove(&self, index: usize) -> AttributeEntry
pub(crate) fn remove(&self, index: usize) -> AttributeEntry
Remove an attribute by index, returning the entry.
Sourcepub(crate) fn set(&self, index: usize, entry: AttributeEntry)
pub(crate) fn set(&self, index: usize, entry: AttributeEntry)
Set an attribute entry by index.
Sourcepub(crate) fn ensure_dom(
&self,
index: usize,
element: &Element,
) -> DomRoot<Attr>
pub(crate) fn ensure_dom( &self, index: usize, element: &Element, ) -> DomRoot<Attr>
Ensure entry at index is a Dom Attr node, materializing if needed.
Returns a DomRoot<Attr>.
This method carefully splits the mutable borrow around the Attr::new()
allocation so that GC tracing can safely borrow the storage.